@@ -14,8 +14,8 @@ from pymodelextractor.learners.observation_table_learners.observation_table impo
 from pythautomata.automata.wheighted_automaton_definition.weighted_state import WeightedState
 
 class BoundedPDFAQuantizationNAryTreeLearner(PDFAQuantizationNAryTreeLearner):
-    def __init__(self, partitioner, max_states, max_query_length, max_seconds_run=None, generate_partial_hipothesis = False, pre_cache_queries_for_building_hipothesis = False, check_probabilistic_hipothesis = True):
-        super().__init__(partitioner, pre_cache_queries_for_building_hipothesis, check_probabilistic_hipothesis)
+    def __init__(self, partitioner, max_states, max_query_length, max_seconds_run=None, generate_partial_hipothesis = False, pre_cache_queries_for_building_hipothesis = False, check_probabilistic_hipothesis = True, exhaust_counterexample = False):
+        super().__init__(partitioner, pre_cache_queries_for_building_hipothesis, check_probabilistic_hipothesis, exhaust_counterexample)
         self._max_states = max_states
         self._max_query_length = max_query_length
         self._max_seconds_run = max_seconds_run
