@@ -22,6 +22,7 @@ from tests.learners_tests.test_pac_batch_teacher_quant import TestPACBatchTeache
 from tests.learners_tests.test_pdfa_quantization_n_ary_tree_learner_running_example \
      import TestPDFAQuantizantionNAryTreeLearnerRunningExample
 from tests.learners_tests.test_mm_lstar_learner import TestMMLStarLearner
+from tests.learners_tests.test_general_lstar_learner import TestGeneralLStarLearner
 
 
 def run():
@@ -34,7 +35,6 @@ def run():
                               TestKearnsVaziraniLearner,
                               TestLStarLearner,
                               TestPDFATeachersLStar,
-                              TestPDFATeachersLStarCol,
                               TestPACBooleanModelTeachers, 
                               TestBoundedPDFAQuantizantionNAryTreeLearner, 
                               TestPDFAQuantizantionNAryTreeLearner,
@@ -44,8 +44,9 @@ def run():
                               TestPDFAQuantizantionNAryTreeLearnerMetrics,
                               TestPACBatchTeacherQuant,
                               TestPDFAQuantizantionNAryTreeLearnerRunningExample,
-                              TestMMLStarLearner, TestPDFATeachersLStarCol]
-
+                              TestMMLStarLearner,
+                              TestGeneralLStarLearner,
+                              TestPDFATeachersLStarCol]
      loader = TestLoader()
      suites_list = []
      for test_class in test_classes_to_run:
